@@ -54,7 +54,7 @@ c            need programing
 c            need programing 
 
        data cos2ghe( kgzai ,-1 )/ 23 /  ! regptcl XI-
-c       data cos2ghe( kx ,-1 )/ 24 /  ! kx OMEGA-
+       data cos2ghe( kbomega, -1 )/ 24 /  ! kx OMEGA-
 c            need programing 
        data anticos2ghe( knuc ,0 )/ 25 /  ! antip ANTINEUTRON
 c            need programing 
@@ -69,7 +69,7 @@ c            need programing
        data anticos2ghe( kgzai ,0 )/ 30 /  ! antip ANTIXI0
 c            need programing 
        data anticos2ghe( kgzai ,1 )/ 31 /  ! antip ANTIXI+
-c        data cos2ghe( kx ,1 )/ 32 /  ! kx ANTIOMEGA+
+       data cos2ghe( kbomega, 1)/ 32 /  ! kx ANTIOMEGA+
 c       data cos2ghe( kx ,1 )/ 33 /  ! kx TAU+
 c       data cos2ghe( kx ,-1 )/ 34 /  ! kx TAU-
        data cos2ghe( kdmes ,1 )/ 35 /  ! 0 D+
@@ -150,6 +150,10 @@ c	elseif(code .eq. kdeut) then
            endif
         elseif(code .eq. keta) then
 	   ghecode = cos2ghe(keta, 0)
+	elseif(code .eq. kbomega) then
+	   ghecode = cos2ghe(kbomega, charge)
+	elseif(code .eq. klambdac) then
+	   ghecode = cos2ghe(klambdac, charge)
         else
            write(msg, *)
      *     ' cosmos code=', code, 'charge=',charge,
