@@ -10,8 +10,12 @@ c
 #define GENERIC
 #elif defined PCLinux
 #define GENERIC
+#elif defined PCLinuxIFC
+#define GENERIC
 #elif defined MACOSX
 #define GENERIC
+#elif defined CF_AlphaLinux
+#define GENERIC
 #endif
 
 
@@ -64,3 +68,5 @@ c
         call getenv('USER',user)
         end
 #endif
+
+
