@@ -55,13 +55,27 @@ c              reset position and angle.
             icon =0
          endif
          if(icon .eq. 0) then
+            if(Job .ne. 'newflesh') then
+c
+c                  for newflesh, next is managed by chookBgEvent
+c
+               EventsInTheRun = EventsInTheRun + 1
+               if(Job .ne. 'flesh') then
+                  EventNo = EventNo + 1
+               endif
+            endif
             call cupdtPrimC  ! update counter for each comp.
                              ! which is not rejected. 
+         elseif( DestEventNo(2) .lt. 0 ) then
+            if(Job .ne. 'newflesh') then
+               EventsInTheRun = EventsInTheRun + 1
+               if(Job .ne. 'flesh') then
+                  EventNo = EventNo + 1
+               endif
+            endif
          endif
       enddo
 
-
-
  10   continue
       end
 #if defined NEXT486
@@ -539,6 +553,7 @@ c       ************************* see if geomagnetic cut or not.
 #include "Zglobalc.h"
 #include "Zobs.h"
 #include "Zobsp.h"
+#include "Zcode.h"
 #include "Ztrack.h"
 #include "ZrigCut.h"
 
