@@ -86,7 +86,7 @@ c/////////
 cc      cc#define DEBUG 1
 
 
-
+      logical reset
       real*8 cosangle
       character*70 msg
       integer nextwhere, never
@@ -133,7 +133,13 @@ c         (or reaches BorderHeightL)  If so, reset MovedTrack.
       call checkstat('after cifXObsSite')
 #endif
       if(Trace .ne. 0) then
-         call cputTrInfo        ! put trace info.
+         if( mod(Trace, 10) .le. 2) then
+            call cputTrInfo     ! put trace info.
+         elseif(mod(Trace,10) .le. 4) then
+            if( TrackBefMove.pos.height .le. HeightList(1)) then
+               call cputTrInfo  ! put trace info.
+            endif
+         endif
       endif
 #if DETAILED_TRACKING >= 3
 c            the user may kill the ptcl
@@ -173,11 +179,24 @@ c              stack current ptcl
          call cpush(MovedTrack)
       elseif(MoveStat .eq. ToInteract ) then
          if(Zfirst.pos.depth .eq. 0.) then
+            if(  (MovedTrack.p.code .ge. kpion  .and. 
+     *            MovedTrack.p.code .le. knuc ) .or.
+     *         MovedTrack.p.code .eq. kgnuc ) then
+               if(IntInfArray(ProcessNo).process .eq. 'coll') then
+                  reset = .true.
+               else
+                  reset = .false.
+               endif
+            else
+               reset = .true.
+            endif
+            if(reset) then
 c             reset minimum time to reach the obs level (time from this
 c             hight to the obs. level), if no mag. exists until
 c                  the first collision point. or ptcl goes streight
-            call cresetTimer(MovedTrack)
-            Zfirst = MovedTrack
+               call cresetTimer(MovedTrack)
+               Zfirst = MovedTrack
+            endif
          endif
 #if DETAILED_TRACKING >= 1 
          call cobservation(4)
@@ -292,7 +311,7 @@ c                  the first collision point. or ptcl goes streight
      *     ObsPlane .ne. 3) then
          call csetMinTime(aTrack)
       else
-c         MovedTrack.t = 0.     ! bug bef uv6.09
+c         MovedTrack.t = 0.     ! bug bef uv6.09 ;;; but why commentout ??? 
       endif
       end
 
